@@ -41,7 +41,7 @@ class GiteaHandler(BaseHookHandler):
         for commit in commits:
             files = []
             for kind in ('added', 'modified', 'removed'):
-                files.extend(commit.get(kind, []))
+                files.extend(commit.get(kind, []) or [])
             timestamp = dateparse(commit['timestamp'])
             change = {
                 'author': '{} <{}>'.format(commit['author']['name'],
@@ -135,6 +135,7 @@ class GiteaHandler(BaseHookHandler):
         except Exception as exception:
             raise ValueError('Error loading JSON: ' + str(exception))
 
+
         if secret is not None:
             p = Properties()
             p.master = self.master
